@@ -360,7 +360,8 @@ def create_python_script(func, args, kwargs, temp_input, user_docker, docker_she
         fp.write("\tos.makedirs(os.path.dirname(dir), exist_ok=True)\n")
         fp.write("\tsys.path.insert(0, os.path.dirname(dir))\n")
         fp.write(f"for link in {links}:\n")  # ln all paths
-        fp.write("\tos.symlink(os.path.join(os.getcwd(), link[1]), link[0])\n")
+        fp.write("\tif not os.path.exists(link[0]):\n")
+        fp.write("\t\tos.symlink(os.path.join(os.getcwd(), link[1]), link[0])\n")
         fp.write(f"func = cloudpickle.loads(base64.decodebytes({encoded_func}))\n")
         fp.write(f"patch_system_calls = cloudpickle.loads(base64.decodebytes({encoded_pickled_patch}))\n")
         fp.write(f"args = cloudpickle.loads(base64.decodebytes({encoded_args}))\n")
@@ -440,7 +441,7 @@ def execute_remote(func, args, kwargs, toolchest_key, remote_output_directory, t
             compress_inputs=True,
             pip_dependencies=pip_packages_string,
             retain_base_directory=True,
-            run_location=provider,
+            provider=provider,
         )
         status_response = remote_run.get_status(return_error=True)
         status = status_response['status']
